@@ -3,10 +3,13 @@
 #' A raw interface to proj_trans_generic in 'PROJ => 6', if it is available.
 #'
 #' Input 'x' is assumed to be 2-columns of "x", then "y" coordinates. If "z" or
-#' "t" is required pass these in as named vectors with "z_" and "t_". These
-#' are left empty (zero-length) internally by default, if possible but it seems that
-#' z must always match the length of `x` `y` if 'xyz' is the output, so for safety this
-#' is always initialized as a zero value vector.
+#' "t" is required pass these in as named vectors with "z_" and "t_". For simplifying reasons
+#' `z_` and `t_` must always match the length of `x` `y`. Both default to 0, and are automatically
+#' recycled to the number of rows in `x` so it's pretty flexible.
+#'
+#' Values that are detected out of bounds by library PROJ are allowed, we return `Inf` in this
+#' case, rather than the error "tolerance condition error".
+#'
 #' @param source projection of input coordinates (must be named)
 #' @param target projection for output coordinates
 #' @param x input coordinates (x,y, list or matrix see `z_` and `t_`)
@@ -23,7 +26,7 @@
 #'  proj_trans_generic(cbind(147, -42), z_ = -2, "+proj=laea", source = "epsg:4326")
 #'  proj_trans_generic(cbind(147, -42), z_ = -2, t_ = 1, "+proj=laea", source = "epsg:4326")
 #'  }
-proj_trans_generic <- function(x, target, ..., source = NULL, z_ = 0, t_ = numeric(0)) {
+proj_trans_generic <- function(x, target, ..., source = NULL, z_ = 0, t_ = 0) {
   if (!ok_proj6()) {
     stop("'proj_trans_generic()' is not functional on this system")
 
@@ -38,8 +41,14 @@ proj_trans_generic <- function(x, target, ..., source = NULL, z_ = 0, t_ = numer
   if (n < 1) stop("must be at least one coordinate")
   y <- x[,2L, drop = TRUE]
   x <- x[,1L, drop = TRUE]
-  if (length(z_) < 1) z_ <- 0
-  if (length(z_) < length(x)) z_ <- rep(z_,  length.out = length(x))
+  z_ <- rep(z_,  length.out = length(x))
+  t_ <- rep(t_,  length.out = length(x))
+
+ lx <- length(x)
+
+  if (!(lx > 0 && length(z_) == lx && length(t_) == lx && is.numeric(z_) && is.numeric(t_) )) {
+    stop("x, z_, t_ must be numeric and compatible lengths")
+  }
   result <- .C("PROJ_proj_trans_generic",
            src_ = as.character(source), tgt_ = as.character(target),
            n = as.integer(n),
